/*
 * jQuery FlexSlider v2.7.1
 * https://www.woocommerce.com/flexslider/
 *
 * Copyright 2012 WooThemes
 * Free to use under the GPLv2 and later license.
 * http://www.gnu.org/licenses/gpl-2.0.html
 *
 * Contributing author: Tyler Smith (@mbmufffin)
 *
 */
/* ====================================================================================================================
 * RESETS
 * ====================================================================================================================*/
.flex-container a:hover,
.flex-slider a:hover {
  outline: none;
}
.slides,
.slides > li,
.flex-control-nav,
.flex-direction-nav {
  margin: 0;
  padding: 0;
  list-style: none;
}
.flex-pauseplay span {
  text-transform: capitalize;
}
/* ====================================================================================================================
 * BASE STYLES
 * ====================================================================================================================*/
.flexslider {
  margin: 0;
  padding: 0;
}
.flexslider .slides > li {
  display: none;
  -webkit-backface-visibility: hidden;
}
.flexslider .slides img {
  width: 100%;
  display: block;
}
.flexslider .slides:after {
  content: "\0020";
  display: block;
  clear: both;
  visibility: hidden;
  line-height: 0;
  height: 0;
}
html[xmlns] .flexslider .slides {
  display: block;
}
* html .flexslider .slides {
  height: 1%;
}
.no-js .flexslider .slides > li:first-child {
  display: block;
}
/* ====================================================================================================================
 * DEFAULT THEME
 * ====================================================================================================================*/
.flexslider {
  background: #fff;
  position: relative;
  zoom: 1;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: '' 0 1px 4px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: '' 0 1px 4px rgba(0, 0, 0, 0.2);
  -o-box-shadow: '' 0 1px 4px rgba(0, 0, 0, 0.2);
  box-shadow: '' 0 1px 4px rgba(0, 0, 0, 0.2);
}
.flexslider .slides {
  zoom: 1;
}
.flexslider .slides img {
  height: auto;
  -moz-user-select: none;
}
.flex-viewport {
  max-height: 2000px;
  -webkit-transition: all 1s ease;
  -moz-transition: all 1s ease;
  -ms-transition: all 1s ease;
  -o-transition: all 1s ease;
  transition: all 1s ease;
}
.loading .flex-viewport {
  max-height: 300px;
}
@-moz-document url-prefix() {
  .loading .flex-viewport {
    max-height: none;
  }
}
.carousel li {
  margin-right: 5px;
}
.flex-pauseplay a {
  display: block;
  width: 20px;
  height: 20px;
  position: absolute;
  bottom: 5px;
  left: 10px;
  opacity: 0.8;
  z-index: 10;
  overflow: hidden;
  cursor: pointer;
  color: #000;
}
.flex-pauseplay a:before {
  font-family: "flexslider-icon";
  font-size: 20px;
  display: inline-block;
  content: '\f004';
}
.flex-pauseplay a:hover {
  opacity: 1;
}
.flex-pauseplay a.flex-play:before {
  content: '\f003';
}
.flex-control-nav {
    width: auto;
    position: absolute;
    bottom: -40px;
    text-align: center;
    left: 50%;
    transform: translateX(-50%);
}
.flex-control-nav li {
  margin: 0 6px;
  display: inline-block;
  zoom: 1;
  *display: inline;
}
.flex-control-paging li a {
  width: 11px;
  height: 11px;
  display: block;
  background: #666;
  background: rgba(0, 0, 0, 0.5);
  cursor: pointer;
  text-indent: -9999px;
  -webkit-box-shadow: inset 0 0 3px rgba(0, 0, 0, 0.3);
  -moz-box-shadow: inset 0 0 3px rgba(0, 0, 0, 0.3);
  -o-box-shadow: inset 0 0 3px rgba(0, 0, 0, 0.3);
  box-shadow: inset 0 0 3px rgba(0, 0, 0, 0.3);
  -webkit-border-radius: 20px;
  -moz-border-radius: 20px;
  border-radius: 20px;
}
.flex-control-paging li a:hover {
  background: #333;
  background: rgba(0, 0, 0, 0.7);
}
.flex-control-paging li a.flex-active {
  background: #000;
  background: rgba(0, 0, 0, 0.9);
  cursor: default;
}
.flex-control-thumbs {
  margin: 5px 0 0;
  position: static;
  overflow: hidden;
}
.flex-control-thumbs li {
  width: 25%;
  float: left;
  margin: 0;
}
.flex-control-thumbs img {
  width: 100%;
  height: auto;
  display: block;
  opacity: .7;
  cursor: pointer;
  -moz-user-select: none;
  -webkit-transition: all 1s ease;
  -moz-transition: all 1s ease;
  -ms-transition: all 1s ease;
  -o-transition: all 1s ease;
  transition: all 1s ease;
}
.flex-control-thumbs img:hover {
  opacity: 1;
}
.flex-control-thumbs .flex-active {
  opacity: 1;
  cursor: default;
}
/* ====================================================================================================================
 * RESPONSIVE
 * ====================================================================================================================*/
@media screen and (max-width: 860px) {
  .flex-direction-nav .flex-prev {
    opacity: 1;
    left: 10px;
  }
  .flex-direction-nav .flex-next {
    opacity: 1;
    right: 10px;
  }
}

/* ====================================================================================================================
 * IDEABOX
 * ====================================================================================================================*/
.slider-multiple .carousel.flexslider{
    ul.slides{
        display: flex;
        align-items: stretch;
        li{
            background: #FFF;
            min-height: 100%;
            border: 1px solid #e6e6e6;
            .flex-caption{
                padding: 4rem 2rem;
                .flex-caption-inner{
                    h2{
                        line-height: 16px;
                        margin-top: 0;
                    }
                    p{
                        display: none;
                    }
		    .documentByLine{
			    color: #d7004e;
			    font-family: Abel;
			    padding: 1rem 0;
			    abbr{
				    border-bottom: none;
				    text-decoration: none;
			    }
		    }
                }
            }
            .read-next-line{
                display: none;
            }
            .slider_multiple_link{
                letter-spacing: -0.05em;
                font-size: 17.6px;
                color: #000;
            }
            .image-background {
                width: 100%;
                padding-top: 60%;
                background-repeat: no-repeat;
                background-size: cover;
                background-position: center;
            }
        }
    }
    .flex-direction-nav {
        display: flex;
        flex-flow: row nowrap;
        justify-content: flex-end;
        li{
            background: #000000 !important;
            margin-top: 1em;
            margin-bottom: 0.25em;
            line-height: 1.5em;
            display: list-item;
            width: 60px;
            height: 60px;
            margin-right: 0;
            overflow: hidden;
            a{
                position: relative;
                color: #000;
                height: 100%;
                width: 100%;
                display: block;
                opacity: 0.5;
                &:hover,
                &:active,
                &:focus{
                    opacity: 1;
                }
                &::before {
                    font-family: "Font Awesome 5 Free";
                    font-weight: 900;
                    color: #FFF;
                    font-size: 28px;
                    position: absolute;
                    height: 100%;
                    width: 100%;
                    display: flex;
                    justify-content: center;
                    align-items: center;
                }
                &:not(.flex-disabled):hover{
                    opacity: 1;
                }
                &.flex-prev::before{
                    content: "\f104";
                }
                &.flex-next::before{
                    content: "\f105";
                }
            }
        }
    }
    &.one{
        .flex-control-nav{
            display: none
        }
        ul.slides li{
            margin-right: 5px !important;
	    margin-bottom: 0 !important;
	    margin-left: 0 !important;
            .flex-caption{
                padding: 0;
                .flex-caption-inner{
                    padding: 4rem;
                    background-color: #000000;
                    position: absolute;
                    z-index: 1;
                    width: 25%;
                    margin-top: -300px;
                    height: 300px;
                    width: 300px;
                    .slider_multiple_link{
                        color: #fff;
                        font-size: 3rem;
                    }
                    p {
                        display: block;
                        a{
                            font-family: Open Sans;
                            font-size: 1.6rem;
                            color: #ffffff;
                            line-height: 3.2rem;
                        }
                    }
                    &::after{
                        content: "";
                        background: linear-gradient(to bottom,transparent ,#000000,#000000);
                        width: 100%;
                        position: absolute;
                        bottom: 0;
                        height: 8.5em;
                        left: 0;
                    }
                }
            }
            .read-next-line{
                display: block;
                display: block;
                position: absolute;
                bottom: 0;
                margin-left: 2em;
                padding: 1em;
                background: #d7004e;
                z-index: 2;
                margin-bottom: 1px;
                a{
                    color: #ffffff;
                }
            }
        }
        .flex-direction-nav{
            margin-right: 2px;
            li{
                margin-top: 0;
                background-color: #d7004e !important;
                transform: translateY(-61px);
                margin-right: -1px;
                a{
                    color: #d7004e !important;
                }
            }
        }
        & + .align-right{
            display: none;
        }
    }
}
@media (max-width: 992px) {
    .slider-multiple .carousel.flexslider.one ul.slides li .flex-caption .flex-caption-inner{
        position: relative;
        margin-top: 0;
        height: auto;
        width: auto;
        padding: 3rem 2rem;
    }
    .slider-multiple .carousel.flexslider.one .flex-direction-nav li{
        transform: none;
    }
}
