!function(n){function t(i){var n=i;return window.innerWidth<900&&(n=3),window.innerWidth<600&&(n=2),window.innerWidth<480&&(n=1),n}n(".flexslider").each(function(){var i=n(this).attr("data-slider");n(this).flexslider({animation:"slide",animationLoop:!1,itemWidth:210,itemMargin:5,minItems:t(i),maxItems:t(i),start:function(i){n("body").removeClass("loading")}})}),n(document).ready(function(){n(".iaweb-mosaic-slick").each(function(){n(this).slick()})})}(jQuery);